import os
import json
import click
from .. import const
from ..templates import templates


def initialize(template_name, disable_oninit=False):
    template = templates[template_name]
    schema = template['body']
    schema["version"] = '0.0.0'
    schema["config"] = {}
    schema["dependencies"] = schema.get("dependencies",{"prod": [], "common": [], "dev": []})
    schema["environment"] = ""
    schema["use_environment"] = True
    current_dir = os.path.basename(os.getcwd())

    # Get inputs
    schema["name"] = click.prompt('Enter project name', default=current_dir)
    schema["description"] = click.prompt('Enter decription', default="")
    schema["author"] = click.prompt('Enter author name', default="")
    schema["author_email"] = click.prompt('Enter author email', default="")
    schema["url"] = click.prompt('Enter url', default="")

    oninit = template.get('oninit', None)
    if oninit and not disable_oninit:
        oninit()
    with open(const.filename, 'wt') as s:
        json.dump(schema, s, indent=4, sort_keys=True)
    click.echo('Successfully initialized ' +
               const.filename+f' with {template_name} template.')



def django_oninit():
    print("Thanks for using django template!!!")


django = {
    "body": {
        "scripts": {
            "start": {
                "command": "python manage.py runserver",
                "description": "Run Django server"
            },
            "mig": {
                "command": "python manage.py migrate",
                "description": "Migrate database"
            },
            "mkmig": {
                "command": "python manage.py makemigrations",
                "description": "Make migrations"
            }
        }
    },
    "oninit":django_oninit
}



import click
from typing import List
from ..package import MYPReader
from ..globals import runScriptDirectly, pip_cmd, parse_requirements
from ..__main__ import main


@main.command("get")
@click.option('--dev', required=False, is_flag=True, help="Get packages as development dependency")
@click.option('--prod', required=False, is_flag=True, help="Get packages as production dependency")
@click.argument('package_names', required=True, nargs=-1)
def get_command(dev: bool, prod: bool, package_names: List[str]) -> None:
    """Get packages"""
    myp: MYPReader = MYPReader()
    package_scope: str = "common" if dev+prod != 1 else ("prod" if prod else "dev")
    myp.add_dependency(package_names, package_scope)
    runScriptDirectly(pip_cmd(f"install {' '.join(package_names)}"))
    myp.write()


@main.command("get:deps")
@click.option('--dev', required=False, is_flag=True, help="Get packages as development dependency")
@click.option('--prod', required=False, is_flag=True, help="Get packages as production dependency")
def get_deps_command(dev: bool, prod: bool) -> None:
    """Get packages in myp.json"""
    myp: MYPReader = MYPReader()
    deps: List[str] = myp.get_dependencies(
        "dev" if dev else ("prod" if prod else "all"))
    runScriptDirectly(pip_cmd(f"install {' '.join(deps)}"))


@main.command("get:load-from")
@click.option('--dev', required=False, is_flag=True, help="Get packages as development dependency")
@click.option('--prod', required=False, is_flag=True, help="Get packages as production dependency")
@click.argument('file_name', default='requirements.txt')
def get_load_from_reqs_command(dev: bool, prod: bool, file_name: str) -> None:
    """Get dependencies in requirements file"""
    myp: MYPReader = MYPReader()
    reqs: List[str] = parse_requirements(file_name)
    reqs_scope: str = "common" if dev+prod != 1 else ("prod" if prod else "dev")
    myp.add_dependency(reqs, reqs_scope)
    runScriptDirectly(pip_cmd(f"install {' '.join(reqs)}"))
    myp.write()



import setuptools
from myp import MYPReader

with open("README.md","r") as fh:
    long_description = fh.read()

myp = MYPReader()

setuptools.setup(
    name=myp.get_data("name"),
    version=myp.get_data("version"),
    author=myp.get_data("author"),
    author_email=myp.get_data("author_email"),
    description=myp.get_data("description"),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=myp.get_data("url"),
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development",
        "Natural Language :: English"
    ],
    install_requires=myp.get_dependencies("prod"),
    setup_requires=myp.get_dependencies("prod"),
    python_requires='>=3.6',
    entry_points='''
        [console_scripts]
        myp=myp.__main__:cli
    ''',
)